/****************************************************************************
** Meta object code from reading C++ file 'imageitem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/imageitem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imageitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QShortcutEx_t {
    QByteArrayData data[1];
    char stringdata0[12];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QShortcutEx_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QShortcutEx_t qt_meta_stringdata_QShortcutEx = {
    {
QT_MOC_LITERAL(0, 0, 11) // "QShortcutEx"

    },
    "QShortcutEx"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QShortcutEx[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void QShortcutEx::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QShortcutEx::staticMetaObject = { {
    QMetaObject::SuperData::link<QShortcut::staticMetaObject>(),
    qt_meta_stringdata_QShortcutEx.data,
    qt_meta_data_QShortcutEx,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QShortcutEx::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QShortcutEx::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QShortcutEx.stringdata0))
        return static_cast<void*>(this);
    return QShortcut::qt_metacast(_clname);
}

int QShortcutEx::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QShortcut::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_AnimationWidget_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AnimationWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AnimationWidget_t qt_meta_stringdata_AnimationWidget = {
    {
QT_MOC_LITERAL(0, 0, 15) // "AnimationWidget"

    },
    "AnimationWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AnimationWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void AnimationWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject AnimationWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DLabel::staticMetaObject>(),
    qt_meta_stringdata_AnimationWidget.data,
    qt_meta_data_AnimationWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AnimationWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AnimationWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AnimationWidget.stringdata0))
        return static_cast<void*>(this);
    return DLabel::qt_metacast(_clname);
}

int AnimationWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ImageItem_t {
    QByteArrayData data[15];
    char stringdata0[161];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ImageItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ImageItem_t qt_meta_stringdata_ImageItem = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ImageItem"
QT_MOC_LITERAL(1, 10, 9), // "trashFile"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 8), // "filePath"
QT_MOC_LITERAL(4, 30, 7), // "onPrint"
QT_MOC_LITERAL(5, 38, 10), // "onShowMenu"
QT_MOC_LITERAL(6, 49, 12), // "onOpenFolder"
QT_MOC_LITERAL(7, 62, 6), // "onCopy"
QT_MOC_LITERAL(8, 69, 13), // "onShortcutDel"
QT_MOC_LITERAL(9, 83, 18), // "paintRequestedAsyn"
QT_MOC_LITERAL(10, 102, 9), // "DPrinter*"
QT_MOC_LITERAL(11, 112, 8), // "_printer"
QT_MOC_LITERAL(12, 121, 12), // "QVector<int>"
QT_MOC_LITERAL(13, 134, 9), // "pageRange"
QT_MOC_LITERAL(14, 144, 16) // "paintRequestSync"

    },
    "ImageItem\0trashFile\0\0filePath\0onPrint\0"
    "onShowMenu\0onOpenFolder\0onCopy\0"
    "onShortcutDel\0paintRequestedAsyn\0"
    "DPrinter*\0_printer\0QVector<int>\0"
    "pageRange\0paintRequestSync"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ImageItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   57,    2, 0x0a /* Public */,
       5,    0,   58,    2, 0x0a /* Public */,
       6,    0,   59,    2, 0x0a /* Public */,
       7,    0,   60,    2, 0x0a /* Public */,
       8,    0,   61,    2, 0x0a /* Public */,
       9,    2,   62,    2, 0x08 /* Private */,
      14,    1,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 12,   11,   13,
    QMetaType::Void, 0x80000000 | 10,   11,

       0        // eod
};

void ImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ImageItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->trashFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->onPrint(); break;
        case 2: _t->onShowMenu(); break;
        case 3: _t->onOpenFolder(); break;
        case 4: _t->onCopy(); break;
        case 5: _t->onShortcutDel(); break;
        case 6: _t->paintRequestedAsyn((*reinterpret_cast< DPrinter*(*)>(_a[1])),(*reinterpret_cast< const QVector<int>(*)>(_a[2]))); break;
        case 7: _t->paintRequestSync((*reinterpret_cast< DPrinter*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ImageItem::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageItem::trashFile)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<DLabel::staticMetaObject>(),
    qt_meta_stringdata_ImageItem.data,
    qt_meta_data_ImageItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ImageItem.stringdata0))
        return static_cast<void*>(this);
    return DLabel::qt_metacast(_clname);
}

int ImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ImageItem::trashFile(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
